unit HTMLView;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Buttons, ExtCtrls, OleCtrls, SHDocVw, ComObj;

type
  THTMLViewerFrm = class(TForm)
    Toolbar: TPanel;
    CloseBtn: TSpeedButton;
    BackBtn: TSpeedButton;
    ForwardBtn: TSpeedButton;
    MainPnl: TPanel;
    WebBrowser: TWebBrowser;
    PrintBtn: TSpeedButton;
    HomeBtn: TSpeedButton;
    SelectAllBtn: TSpeedButton;
    CopyBtn: TSpeedButton;
    procedure CloseBtnClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure BackBtnClick(Sender: TObject);
    procedure ForwardBtnClick(Sender: TObject);
    procedure PrintBtnClick(Sender: TObject);
    procedure HomeBtnClick(Sender: TObject);
    procedure SelectAllBtnClick(Sender: TObject);
    procedure CopyBtnClick(Sender: TObject);
  private
    { Private declarations }
    HomePage: string;
  public
    { Public declarations }
  end;

var
  HTMLViewerFrm: THTMLViewerFrm;

implementation

{$R *.DFM}
{$R HTML.RES} // Compiles in the resource holding the web-pages and
              // any support files.

procedure THTMLViewerFrm.CloseBtnClick(Sender: TObject);
begin
  Close;
end;

procedure THTMLViewerFrm.FormCreate(Sender: TObject);
var
  ModuleName: array[0..255] of Char;
begin
  try
    { The crucial lines of code. GetModuleName retrieves the full file
      spec of the application... }
    GetModuleFileName(hInstance, ModuleName, 255);
    { ...which is then compiled into a 'Res:' URL pointing to the first
      page to be displayed... }
    HomePage := 'res://' + StrPas(ModuleName) + '/RT_HTML/INDEX_HTML';
    { ...and the web-browser is pointed at it. Simple as that! }
    WebBrowser.Navigate(HomePage);
  except
    on Exception do
      ShowMessage('Unable to load HTML pages from resource');
  end;
end;

procedure THTMLViewerFrm.BackBtnClick(Sender: TObject);
begin
  try
    WebBrowser.GoBack;
  except
    on EOLEException do
    { Ignore errors raised by the browser. }
    ;
  end;
end;

procedure THTMLViewerFrm.ForwardBtnClick(Sender: TObject);
begin
  try
    WebBrowser.GoForward;
  except
    on EOLEException do
    { Ignore errors raised by the browser. }
    ;
  end;
end;

procedure THTMLViewerFrm.PrintBtnClick(Sender: TObject);
begin
  try
    WebBrowser.ExecWB(OLECMDID_PRINT, OLECMDEXECOPT_DODEFAULT);
  except
    on EOLEException do
    { Ignore errors raised by the browser. }
    ;
  end;
end;

procedure THTMLViewerFrm.HomeBtnClick(Sender: TObject);
begin
  try
    WebBrowser.Navigate(HomePage);
  except
    on EOLEException do
    { Ignore errors raised by the browser. }
    ;
  end;
end;

procedure THTMLViewerFrm.SelectAllBtnClick(Sender: TObject);
begin
  try
    WebBrowser.ExecWB(OLECMDID_SELECTALL, OLECMDEXECOPT_DODEFAULT);
  except
    on EOLEException do
    { Ignore errors raised by the browser. }
    ;
  end;
end;

procedure THTMLViewerFrm.CopyBtnClick(Sender: TObject);
{ NOTE: The Copy command does not work -- this may have something to do
  with the fact that the web-page is buried inside the resource file
  (though the Print command works fine). }
begin
  try
    WebBrowser.ExecWB(OLECMDID_COPY, OLECMDEXECOPT_DODEFAULT);
  except
    on EOLEException do
    { Ignore errors raised by the browser. }
    ;
  end;
end;

end.
